@@ -64,22 +64,31 @@ at your option, any later version of Perl 5 you may have available.
 
 =cut
 package Tk::GraphItems;
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 require Tk::GraphItems::TextBox;
 require Tk::GraphItems::Circle;
 require Tk::GraphItems::Connector;
 
 sub TextBox{
-  shift;
-  Tk::GraphItems::TextBox->new(@_);
+    if ($_[0]){
+        shift;
+        return Tk::GraphItems::TextBox->new(@_);
+    }
+    return 'Tk::GraphItems::TextBox';
 }
 
 sub Connector{
-  shift;
-  Tk::GraphItems::Connector->new(@_);
+    if ($_[0]){
+        shift;
+        return Tk::GraphItems::Connector->new(@_);
+    }
+    return 'Tk::GraphItems::Connector';
 }
 sub Circle{
-  shift;
-  Tk::GraphItems::Circle->new(@_);
+    if ($_[0]){
+        shift;
+        return Tk::GraphItems::Circle->new(@_);
+    }
+    return 'Tk::GraphItems::Circle';
 }
 1;
